#include "siotclient.h"
#include <WiFi.h>
#include <HTTPClient.h>

WiFiClient client;
HTTPClient http;

/// @brief declare necessary information for an IoT device
/// @param DeviceId Identificatior of the device, generated by the SIOT Center, at http://siot.soict.ai
/// @param ApiKey Secret key, generated by SIOT Center of an IoT device, at http://siot.soict.ai
/// @return 
void SIOTClient::Checkin(String DeviceId, String ApiKey)
{
    this->DeviceBaseURL = "http://siot.soict.ai/api/devices/" + DeviceId;
    this->ApiKey = "Bearer " + ApiKey;
}

/// @brief Send data to SIOT Api Center for permanent storage
/// @param postdata  Data to be stored. E.g  '{"value":1}'
/// @return http code
int SIOTClient::Send(String AttributeId, String postdata)
{
  http.begin(client, DeviceBaseURL + "/attributes/" + AttributeId);
  http.addHeader("Content-Type", "application/json");
  http.addHeader("Authorization", this->ApiKey);
  
  // Send HTTP POST request and return the http code
  return http.POST(postdata);
}
